# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from oci._vendor import requests  # noqa: F401
from oci._vendor import six

from oci import retry  # noqa: F401
from oci.base_client import BaseClient
from oci.config import get_config_value_or_default, validate_config
from oci.signer import Signer
from oci.util import Sentinel, get_signer_from_authentication_type, AUTHENTICATION_TYPE_FIELD_NAME
from .models import dts_type_mapping
missing = Sentinel("Missing")


class TransferPackageClient(object):
    """
    Data Transfer Service API Specification
    """

    def __init__(self, config, **kwargs):
        """
        Creates a new service client

        :param dict config:
            Configuration keys and values as per `SDK and Tool Configuration <https://docs.cloud.oracle.com/Content/API/Concepts/sdkconfig.htm>`__.
            The :py:meth:`~oci.config.from_file` method can be used to load configuration from a file. Alternatively, a ``dict`` can be passed. You can validate_config
            the dict using :py:meth:`~oci.config.validate_config`

        :param str service_endpoint: (optional)
            The endpoint of the service to call using this client. For example ``https://iaas.us-ashburn-1.oraclecloud.com``. If this keyword argument is
            not provided then it will be derived using the region in the config parameter. You should only provide this keyword argument if you have an explicit
            need to specify a service endpoint.

        :param timeout: (optional)
            The connection and read timeouts for the client. The default values are connection timeout 10 seconds and read timeout 60 seconds. This keyword argument can be provided
            as a single float, in which case the value provided is used for both the read and connection timeouts, or as a tuple of two floats. If
            a tuple is provided then the first value is used as the connection timeout and the second value as the read timeout.
        :type timeout: float or tuple(float, float)

        :param signer: (optional)
            The signer to use when signing requests made by the service client. The default is to use a :py:class:`~oci.signer.Signer` based on the values
            provided in the config parameter.

            One use case for this parameter is for `Instance Principals authentication <https://docs.cloud.oracle.com/Content/Identity/Tasks/callingservicesfrominstances.htm>`__
            by passing an instance of :py:class:`~oci.auth.signers.InstancePrincipalsSecurityTokenSigner` as the value for this keyword argument
        :type signer: :py:class:`~oci.signer.AbstractBaseSigner`

        :param obj retry_strategy: (optional)
            A retry strategy to apply to all calls made by this service client (i.e. at the client level). There is no retry strategy applied by default.
            Retry strategies can also be applied at the operation level by passing a ``retry_strategy`` keyword argument as part of calling the operation.
            Any value provided at the operation level will override whatever is specified at the client level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.
        """
        validate_config(config, signer=kwargs.get('signer'))
        if 'signer' in kwargs:
            signer = kwargs['signer']

        elif AUTHENTICATION_TYPE_FIELD_NAME in config:
            signer = get_signer_from_authentication_type(config)

        else:
            signer = Signer(
                tenancy=config["tenancy"],
                user=config["user"],
                fingerprint=config["fingerprint"],
                private_key_file_location=config.get("key_file"),
                pass_phrase=get_config_value_or_default(config, "pass_phrase"),
                private_key_content=config.get("key_content")
            )

        base_client_init_kwargs = {
            'regional_client': True,
            'service_endpoint': kwargs.get('service_endpoint'),
            'base_path': '/20171001',
            'service_endpoint_template': 'https://datatransfer.{region}.oci.{secondLevelDomain}',
            'skip_deserialization': kwargs.get('skip_deserialization', False)
        }
        if 'timeout' in kwargs:
            base_client_init_kwargs['timeout'] = kwargs.get('timeout')
        self.base_client = BaseClient("transfer_package", config, signer, dts_type_mapping, **base_client_init_kwargs)
        self.retry_strategy = kwargs.get('retry_strategy')

    def attach_devices_to_transfer_package(self, id, transfer_package_label, attach_devices_details, **kwargs):
        """
        Attaches Devices to a Transfer Package


        :param str id: (required)
            ID of the Transfer Job

        :param str transfer_package_label: (required)
            Label of the Transfer Package

        :param oci.dts.models.AttachDevicesDetails attach_devices_details: (required)
            Labels of Transfer Devices to attach

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.39.1/dts/attach_devices_to_transfer_package.py.html>`__ to see an example of how to use attach_devices_to_transfer_package API.
        """
        resource_path = "/transferJobs/{id}/transferPackages/{transferPackageLabel}/actions/attachDevices"
        method = "POST"

        expected_kwargs = ["retry_strategy"]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "attach_devices_to_transfer_package got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "id": id,
            "transferPackageLabel": transfer_package_label
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json"
        }

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=attach_devices_details)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=attach_devices_details)

    def create_transfer_package(self, id, **kwargs):
        """
        Create a new Transfer Package


        :param str id: (required)
            ID of the Transfer Job

        :param str opc_retry_token: (optional)

        :param oci.dts.models.CreateTransferPackageDetails create_transfer_package_details: (optional)
            Creates a New Transfer Package

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.dts.models.TransferPackage`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.39.1/dts/create_transfer_package.py.html>`__ to see an example of how to use create_transfer_package API.
        """
        resource_path = "/transferJobs/{id}/transferPackages"
        method = "POST"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "opc_retry_token",
            "create_transfer_package_details"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "create_transfer_package got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "id": id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-retry-token": kwargs.get("opc_retry_token", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_retry_token_if_needed(header_params)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=kwargs.get('create_transfer_package_details'),
                response_type="TransferPackage")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=kwargs.get('create_transfer_package_details'),
                response_type="TransferPackage")

    def delete_transfer_package(self, id, transfer_package_label, **kwargs):
        """
        deletes a transfer Package


        :param str id: (required)
            ID of the Transfer Job

        :param str transfer_package_label: (required)
            Label of the Transfer Package

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.39.1/dts/delete_transfer_package.py.html>`__ to see an example of how to use delete_transfer_package API.
        """
        resource_path = "/transferJobs/{id}/transferPackages/{transferPackageLabel}"
        method = "DELETE"

        expected_kwargs = ["retry_strategy"]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "delete_transfer_package got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "id": id,
            "transferPackageLabel": transfer_package_label
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json"
        }

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params)

    def detach_devices_from_transfer_package(self, id, transfer_package_label, detach_devices_details, **kwargs):
        """
        Detaches Devices from a Transfer Package


        :param str id: (required)
            ID of the Transfer Job

        :param str transfer_package_label: (required)
            Label of the Transfer Package

        :param oci.dts.models.DetachDevicesDetails detach_devices_details: (required)
            Labels of Transfer Devices to detach

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.39.1/dts/detach_devices_from_transfer_package.py.html>`__ to see an example of how to use detach_devices_from_transfer_package API.
        """
        resource_path = "/transferJobs/{id}/transferPackages/{transferPackageLabel}/actions/detachDevices"
        method = "POST"

        expected_kwargs = ["retry_strategy"]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "detach_devices_from_transfer_package got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "id": id,
            "transferPackageLabel": transfer_package_label
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json"
        }

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=detach_devices_details)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=detach_devices_details)

    def get_transfer_package(self, id, transfer_package_label, **kwargs):
        """
        Describes a transfer package in detail


        :param str id: (required)
            ID of the Transfer Job

        :param str transfer_package_label: (required)
            Label of the Transfer Package

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.dts.models.TransferPackage`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.39.1/dts/get_transfer_package.py.html>`__ to see an example of how to use get_transfer_package API.
        """
        resource_path = "/transferJobs/{id}/transferPackages/{transferPackageLabel}"
        method = "GET"

        expected_kwargs = ["retry_strategy"]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "get_transfer_package got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "id": id,
            "transferPackageLabel": transfer_package_label
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json"
        }

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="TransferPackage")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="TransferPackage")

    def list_transfer_packages(self, id, **kwargs):
        """
        Lists Transfer Packages associated with a transferJob


        :param str id: (required)
            ID of the Transfer Job

        :param str lifecycle_state: (optional)
            filtering by lifecycleState

            Allowed values are: "PREPARING", "SHIPPING", "RECEIVED", "PROCESSING", "PROCESSED", "RETURNED", "DELETED", "CANCELLED", "CANCELLED_RETURNED"

        :param str display_name: (optional)
            filtering by displayName

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.dts.models.MultipleTransferPackages`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.39.1/dts/list_transfer_packages.py.html>`__ to see an example of how to use list_transfer_packages API.
        """
        resource_path = "/transferJobs/{id}/transferPackages"
        method = "GET"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "lifecycle_state",
            "display_name"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "list_transfer_packages got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "id": id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        if 'lifecycle_state' in kwargs:
            lifecycle_state_allowed_values = ["PREPARING", "SHIPPING", "RECEIVED", "PROCESSING", "PROCESSED", "RETURNED", "DELETED", "CANCELLED", "CANCELLED_RETURNED"]
            if kwargs['lifecycle_state'] not in lifecycle_state_allowed_values:
                raise ValueError(
                    "Invalid value for `lifecycle_state`, must be one of {0}".format(lifecycle_state_allowed_values)
                )

        query_params = {
            "lifecycleState": kwargs.get("lifecycle_state", missing),
            "displayName": kwargs.get("display_name", missing)
        }
        query_params = {k: v for (k, v) in six.iteritems(query_params) if v is not missing and v is not None}

        header_params = {
            "accept": "application/json",
            "content-type": "application/json"
        }

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                query_params=query_params,
                header_params=header_params,
                response_type="MultipleTransferPackages")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                query_params=query_params,
                header_params=header_params,
                response_type="MultipleTransferPackages")

    def update_transfer_package(self, id, transfer_package_label, update_transfer_package_details, **kwargs):
        """
        Updates a Transfer Package


        :param str id: (required)
            ID of the Transfer Job

        :param str transfer_package_label: (required)
            Label of the Transfer Package

        :param oci.dts.models.UpdateTransferPackageDetails update_transfer_package_details: (required)
            fields to update

        :param str if_match: (optional)
            The entity tag to match. Optional, if set, the update will be successful only if the
            object's tag matches the tag specified in the request.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.dts.models.TransferPackage`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.39.1/dts/update_transfer_package.py.html>`__ to see an example of how to use update_transfer_package API.
        """
        resource_path = "/transferJobs/{id}/transferPackages/{transferPackageLabel}"
        method = "PUT"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "retry_strategy",
            "if_match"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "update_transfer_package got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "id": id,
            "transferPackageLabel": transfer_package_label
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.retry_strategy
        if kwargs.get('retry_strategy'):
            retry_strategy = kwargs.get('retry_strategy')

        if retry_strategy:
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_transfer_package_details,
                response_type="TransferPackage")
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_transfer_package_details,
                response_type="TransferPackage")



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ComputeGlobalImageCapabilitySchemaVersion(object):
    """
    Compute Global Image Capability Schema Version is a set of all possible capabilities for a collection of images.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ComputeGlobalImageCapabilitySchemaVersion object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this ComputeGlobalImageCapabilitySchemaVersion.
        :type name: str

        :param compute_global_image_capability_schema_id:
            The value to assign to the compute_global_image_capability_schema_id property of this ComputeGlobalImageCapabilitySchemaVersion.
        :type compute_global_image_capability_schema_id: str

        :param display_name:
            The value to assign to the display_name property of this ComputeGlobalImageCapabilitySchemaVersion.
        :type display_name: str

        :param schema_data:
            The value to assign to the schema_data property of this ComputeGlobalImageCapabilitySchemaVersion.
        :type schema_data: dict(str, ImageCapabilitySchemaDescriptor)

        :param time_created:
            The value to assign to the time_created property of this ComputeGlobalImageCapabilitySchemaVersion.
        :type time_created: datetime

        """
        self.swagger_types = {
            'name': 'str',
            'compute_global_image_capability_schema_id': 'str',
            'display_name': 'str',
            'schema_data': 'dict(str, ImageCapabilitySchemaDescriptor)',
            'time_created': 'datetime'
        }

        self.attribute_map = {
            'name': 'name',
            'compute_global_image_capability_schema_id': 'computeGlobalImageCapabilitySchemaId',
            'display_name': 'displayName',
            'schema_data': 'schemaData',
            'time_created': 'timeCreated'
        }

        self._name = None
        self._compute_global_image_capability_schema_id = None
        self._display_name = None
        self._schema_data = None
        self._time_created = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this ComputeGlobalImageCapabilitySchemaVersion.
        The name of the compute global image capability schema version


        :return: The name of this ComputeGlobalImageCapabilitySchemaVersion.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ComputeGlobalImageCapabilitySchemaVersion.
        The name of the compute global image capability schema version


        :param name: The name of this ComputeGlobalImageCapabilitySchemaVersion.
        :type: str
        """
        self._name = name

    @property
    def compute_global_image_capability_schema_id(self):
        """
        **[Required]** Gets the compute_global_image_capability_schema_id of this ComputeGlobalImageCapabilitySchemaVersion.
        The ocid of the compute global image capability schema


        :return: The compute_global_image_capability_schema_id of this ComputeGlobalImageCapabilitySchemaVersion.
        :rtype: str
        """
        return self._compute_global_image_capability_schema_id

    @compute_global_image_capability_schema_id.setter
    def compute_global_image_capability_schema_id(self, compute_global_image_capability_schema_id):
        """
        Sets the compute_global_image_capability_schema_id of this ComputeGlobalImageCapabilitySchemaVersion.
        The ocid of the compute global image capability schema


        :param compute_global_image_capability_schema_id: The compute_global_image_capability_schema_id of this ComputeGlobalImageCapabilitySchemaVersion.
        :type: str
        """
        self._compute_global_image_capability_schema_id = compute_global_image_capability_schema_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this ComputeGlobalImageCapabilitySchemaVersion.
        A user-friendly name for the compute global image capability schema


        :return: The display_name of this ComputeGlobalImageCapabilitySchemaVersion.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ComputeGlobalImageCapabilitySchemaVersion.
        A user-friendly name for the compute global image capability schema


        :param display_name: The display_name of this ComputeGlobalImageCapabilitySchemaVersion.
        :type: str
        """
        self._display_name = display_name

    @property
    def schema_data(self):
        """
        **[Required]** Gets the schema_data of this ComputeGlobalImageCapabilitySchemaVersion.
        The map of each capability name to its ImageCapabilityDescriptor.


        :return: The schema_data of this ComputeGlobalImageCapabilitySchemaVersion.
        :rtype: dict(str, ImageCapabilitySchemaDescriptor)
        """
        return self._schema_data

    @schema_data.setter
    def schema_data(self, schema_data):
        """
        Sets the schema_data of this ComputeGlobalImageCapabilitySchemaVersion.
        The map of each capability name to its ImageCapabilityDescriptor.


        :param schema_data: The schema_data of this ComputeGlobalImageCapabilitySchemaVersion.
        :type: dict(str, ImageCapabilitySchemaDescriptor)
        """
        self._schema_data = schema_data

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this ComputeGlobalImageCapabilitySchemaVersion.
        The date and time the compute global image capability schema version was created, in the format defined by
        `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this ComputeGlobalImageCapabilitySchemaVersion.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ComputeGlobalImageCapabilitySchemaVersion.
        The date and time the compute global image capability schema version was created, in the format defined by
        `RFC3339`__.

        Example: `2016-08-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this ComputeGlobalImageCapabilitySchemaVersion.
        :type: datetime
        """
        self._time_created = time_created

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .host_configuration_metric_group import HostConfigurationMetricGroup
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HostResourceAllocation(HostConfigurationMetricGroup):
    """
    Resource Allocation metric for the host
    """

    def __init__(self, **kwargs):
        """
        Initializes a new HostResourceAllocation object with values from keyword arguments. The default value of the :py:attr:`~oci.opsi.models.HostResourceAllocation.metric_name` attribute
        of this class is ``HOST_RESOURCE_ALLOCATION`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param metric_name:
            The value to assign to the metric_name property of this HostResourceAllocation.
            Allowed values for this property are: "HOST_PRODUCT", "HOST_RESOURCE_ALLOCATION", "HOST_MEMORY_CONFIGURATION", "HOST_HARDWARE_CONFIGURATION", "HOST_CPU_HARDWARE_CONFIGURATION", "HOST_NETWORK_CONFIGURATION", "HOST_ENTITES"
        :type metric_name: str

        :param time_collected:
            The value to assign to the time_collected property of this HostResourceAllocation.
        :type time_collected: datetime

        :param total_cpus:
            The value to assign to the total_cpus property of this HostResourceAllocation.
        :type total_cpus: int

        :param total_memory_in_gb:
            The value to assign to the total_memory_in_gb property of this HostResourceAllocation.
        :type total_memory_in_gb: float

        """
        self.swagger_types = {
            'metric_name': 'str',
            'time_collected': 'datetime',
            'total_cpus': 'int',
            'total_memory_in_gb': 'float'
        }

        self.attribute_map = {
            'metric_name': 'metricName',
            'time_collected': 'timeCollected',
            'total_cpus': 'totalCpus',
            'total_memory_in_gb': 'totalMemoryInGB'
        }

        self._metric_name = None
        self._time_collected = None
        self._total_cpus = None
        self._total_memory_in_gb = None
        self._metric_name = 'HOST_RESOURCE_ALLOCATION'

    @property
    def total_cpus(self):
        """
        Gets the total_cpus of this HostResourceAllocation.
        Total number of CPUs available


        :return: The total_cpus of this HostResourceAllocation.
        :rtype: int
        """
        return self._total_cpus

    @total_cpus.setter
    def total_cpus(self, total_cpus):
        """
        Sets the total_cpus of this HostResourceAllocation.
        Total number of CPUs available


        :param total_cpus: The total_cpus of this HostResourceAllocation.
        :type: int
        """
        self._total_cpus = total_cpus

    @property
    def total_memory_in_gb(self):
        """
        Gets the total_memory_in_gb of this HostResourceAllocation.
        Total amount of usable physical memory in gibabytes


        :return: The total_memory_in_gb of this HostResourceAllocation.
        :rtype: float
        """
        return self._total_memory_in_gb

    @total_memory_in_gb.setter
    def total_memory_in_gb(self, total_memory_in_gb):
        """
        Sets the total_memory_in_gb of this HostResourceAllocation.
        Total amount of usable physical memory in gibabytes


        :param total_memory_in_gb: The total_memory_in_gb of this HostResourceAllocation.
        :type: float
        """
        self._total_memory_in_gb = total_memory_in_gb

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ReservedIP(object):
    """
    An object representing a reserved IP address to be attached or that is already attached to a network load balancer.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ReservedIP object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ReservedIP.
        :type id: str

        """
        self.swagger_types = {
            'id': 'str'
        }

        self.attribute_map = {
            'id': 'id'
        }

        self._id = None

    @property
    def id(self):
        """
        Gets the id of this ReservedIP.
        OCID of the reserved public IP address created with the virtual cloud network.

        Reserved public IP addresses are IP addresses that are registered using the virtual cloud network API.

        Create a reserved public IP address. When you create the network load balancer, enter the OCID of the reserved public IP address in the
        reservedIp field to attach the IP address to the network load balancer. This task configures the network load balancer to listen to traffic on this IP address.

        Reserved public IP addresses are not deleted when the network load balancer is deleted. The IP addresses become unattached from the network load balancer.

        Example: \"ocid1.publicip.oc1.phx.unique_ID\"


        :return: The id of this ReservedIP.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ReservedIP.
        OCID of the reserved public IP address created with the virtual cloud network.

        Reserved public IP addresses are IP addresses that are registered using the virtual cloud network API.

        Create a reserved public IP address. When you create the network load balancer, enter the OCID of the reserved public IP address in the
        reservedIp field to attach the IP address to the network load balancer. This task configures the network load balancer to listen to traffic on this IP address.

        Reserved public IP addresses are not deleted when the network load balancer is deleted. The IP addresses become unattached from the network load balancer.

        Example: \"ocid1.publicip.oc1.phx.unique_ID\"


        :param id: The id of this ReservedIP.
        :type: str
        """
        self._id = id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ExadataInfrastructureContact(object):
    """
    Contact details for Exadata Infrastructure.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ExadataInfrastructureContact object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this ExadataInfrastructureContact.
        :type name: str

        :param phone_number:
            The value to assign to the phone_number property of this ExadataInfrastructureContact.
        :type phone_number: str

        :param email:
            The value to assign to the email property of this ExadataInfrastructureContact.
        :type email: str

        :param is_primary:
            The value to assign to the is_primary property of this ExadataInfrastructureContact.
        :type is_primary: bool

        :param is_contact_mos_validated:
            The value to assign to the is_contact_mos_validated property of this ExadataInfrastructureContact.
        :type is_contact_mos_validated: bool

        """
        self.swagger_types = {
            'name': 'str',
            'phone_number': 'str',
            'email': 'str',
            'is_primary': 'bool',
            'is_contact_mos_validated': 'bool'
        }

        self.attribute_map = {
            'name': 'name',
            'phone_number': 'phoneNumber',
            'email': 'email',
            'is_primary': 'isPrimary',
            'is_contact_mos_validated': 'isContactMosValidated'
        }

        self._name = None
        self._phone_number = None
        self._email = None
        self._is_primary = None
        self._is_contact_mos_validated = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this ExadataInfrastructureContact.
        The name of the Exadata Infrastructure contact.


        :return: The name of this ExadataInfrastructureContact.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ExadataInfrastructureContact.
        The name of the Exadata Infrastructure contact.


        :param name: The name of this ExadataInfrastructureContact.
        :type: str
        """
        self._name = name

    @property
    def phone_number(self):
        """
        Gets the phone_number of this ExadataInfrastructureContact.
        The phone number for the Exadata Infrastructure contact.


        :return: The phone_number of this ExadataInfrastructureContact.
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """
        Sets the phone_number of this ExadataInfrastructureContact.
        The phone number for the Exadata Infrastructure contact.


        :param phone_number: The phone_number of this ExadataInfrastructureContact.
        :type: str
        """
        self._phone_number = phone_number

    @property
    def email(self):
        """
        **[Required]** Gets the email of this ExadataInfrastructureContact.
        The email for the Exadata Infrastructure contact.


        :return: The email of this ExadataInfrastructureContact.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this ExadataInfrastructureContact.
        The email for the Exadata Infrastructure contact.


        :param email: The email of this ExadataInfrastructureContact.
        :type: str
        """
        self._email = email

    @property
    def is_primary(self):
        """
        **[Required]** Gets the is_primary of this ExadataInfrastructureContact.
        If `true`, this Exadata Infrastructure contact is a primary contact. If `false`, this Exadata Infrastructure is a secondary contact.


        :return: The is_primary of this ExadataInfrastructureContact.
        :rtype: bool
        """
        return self._is_primary

    @is_primary.setter
    def is_primary(self, is_primary):
        """
        Sets the is_primary of this ExadataInfrastructureContact.
        If `true`, this Exadata Infrastructure contact is a primary contact. If `false`, this Exadata Infrastructure is a secondary contact.


        :param is_primary: The is_primary of this ExadataInfrastructureContact.
        :type: bool
        """
        self._is_primary = is_primary

    @property
    def is_contact_mos_validated(self):
        """
        Gets the is_contact_mos_validated of this ExadataInfrastructureContact.
        If `true`, this Exadata Infrastructure contact is a valid My Oracle Support (MOS) contact. If `false`, this Exadata Infrastructure contact is not a valid MOS contact.


        :return: The is_contact_mos_validated of this ExadataInfrastructureContact.
        :rtype: bool
        """
        return self._is_contact_mos_validated

    @is_contact_mos_validated.setter
    def is_contact_mos_validated(self, is_contact_mos_validated):
        """
        Sets the is_contact_mos_validated of this ExadataInfrastructureContact.
        If `true`, this Exadata Infrastructure contact is a valid My Oracle Support (MOS) contact. If `false`, this Exadata Infrastructure contact is not a valid MOS contact.


        :param is_contact_mos_validated: The is_contact_mos_validated of this ExadataInfrastructureContact.
        :type: bool
        """
        self._is_contact_mos_validated = is_contact_mos_validated

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MetricExtraction(object):
    """
    Specify metric extraction for SAVED_SEARCH scheduled task execution
    to post to OCI Monitoring.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MetricExtraction object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this MetricExtraction.
        :type compartment_id: str

        :param namespace:
            The value to assign to the namespace property of this MetricExtraction.
        :type namespace: str

        :param metric_name:
            The value to assign to the metric_name property of this MetricExtraction.
        :type metric_name: str

        :param resource_group:
            The value to assign to the resource_group property of this MetricExtraction.
        :type resource_group: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'namespace': 'str',
            'metric_name': 'str',
            'resource_group': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'namespace': 'namespace',
            'metric_name': 'metricName',
            'resource_group': 'resourceGroup'
        }

        self._compartment_id = None
        self._namespace = None
        self._metric_name = None
        self._resource_group = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this MetricExtraction.
        The compartment OCID (/iaas/Content/General/Concepts/identifiers.htm) of the extracted metric.


        :return: The compartment_id of this MetricExtraction.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this MetricExtraction.
        The compartment OCID (/iaas/Content/General/Concepts/identifiers.htm) of the extracted metric.


        :param compartment_id: The compartment_id of this MetricExtraction.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def namespace(self):
        """
        **[Required]** Gets the namespace of this MetricExtraction.
        The namespace of the extracted metric.
        A valid value starts with an alphabetical character and includes only
        alphanumeric characters and underscores (_).


        :return: The namespace of this MetricExtraction.
        :rtype: str
        """
        return self._namespace

    @namespace.setter
    def namespace(self, namespace):
        """
        Sets the namespace of this MetricExtraction.
        The namespace of the extracted metric.
        A valid value starts with an alphabetical character and includes only
        alphanumeric characters and underscores (_).


        :param namespace: The namespace of this MetricExtraction.
        :type: str
        """
        self._namespace = namespace

    @property
    def metric_name(self):
        """
        **[Required]** Gets the metric_name of this MetricExtraction.
        The metric name of the extracted metric.
        A valid value starts with an alphabetical character and includes only
        alphanumeric characters, periods (.), underscores (_), hyphens (-), and dollar signs ($).


        :return: The metric_name of this MetricExtraction.
        :rtype: str
        """
        return self._metric_name

    @metric_name.setter
    def metric_name(self, metric_name):
        """
        Sets the metric_name of this MetricExtraction.
        The metric name of the extracted metric.
        A valid value starts with an alphabetical character and includes only
        alphanumeric characters, periods (.), underscores (_), hyphens (-), and dollar signs ($).


        :param metric_name: The metric_name of this MetricExtraction.
        :type: str
        """
        self._metric_name = metric_name

    @property
    def resource_group(self):
        """
        Gets the resource_group of this MetricExtraction.
        The resourceGroup of the extracted metric.
        A valid value starts with an alphabetical character and includes only
        alphanumeric characters, periods (.), underscores (_), hyphens (-), and dollar signs ($).


        :return: The resource_group of this MetricExtraction.
        :rtype: str
        """
        return self._resource_group

    @resource_group.setter
    def resource_group(self, resource_group):
        """
        Sets the resource_group of this MetricExtraction.
        The resourceGroup of the extracted metric.
        A valid value starts with an alphabetical character and includes only
        alphanumeric characters, periods (.), underscores (_), hyphens (-), and dollar signs ($).


        :param resource_group: The resource_group of this MetricExtraction.
        :type: str
        """
        self._resource_group = resource_group

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AvailabilityDomain(object):
    """
    Availability Domains
    """

    #: A constant which can be used with the ads property of a AvailabilityDomain.
    #: This constant has a value of "AD1"
    ADS_AD1 = "AD1"

    #: A constant which can be used with the ads property of a AvailabilityDomain.
    #: This constant has a value of "AD2"
    ADS_AD2 = "AD2"

    #: A constant which can be used with the ads property of a AvailabilityDomain.
    #: This constant has a value of "AD3"
    ADS_AD3 = "AD3"

    def __init__(self, **kwargs):
        """
        Initializes a new AvailabilityDomain object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param ads:
            The value to assign to the ads property of this AvailabilityDomain.
            Allowed values for this property are: "AD1", "AD2", "AD3"
        :type ads: str

        """
        self.swagger_types = {
            'ads': 'str'
        }

        self.attribute_map = {
            'ads': 'ads'
        }

        self._ads = None

    @property
    def ads(self):
        """
        Gets the ads of this AvailabilityDomain.
        Availability Domain Identifiers

        Allowed values for this property are: "AD1", "AD2", "AD3"


        :return: The ads of this AvailabilityDomain.
        :rtype: str
        """
        return self._ads

    @ads.setter
    def ads(self, ads):
        """
        Sets the ads of this AvailabilityDomain.
        Availability Domain Identifiers


        :param ads: The ads of this AvailabilityDomain.
        :type: str
        """
        allowed_values = ["AD1", "AD2", "AD3"]
        if not value_allowed_none_or_none_sentinel(ads, allowed_values):
            raise ValueError(
                "Invalid value for `ads`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._ads = ads

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DefaultDrgRouteTables(object):
    """
    The default DRG route table for this DRG. Each network type
    has a default DRG route table.

    You can update a network type to use a different DRG route table, but
    each network type must have a default DRG route table. You cannot delete
    a default DRG route table.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DefaultDrgRouteTables object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param vcn:
            The value to assign to the vcn property of this DefaultDrgRouteTables.
        :type vcn: str

        :param ipsec_tunnel:
            The value to assign to the ipsec_tunnel property of this DefaultDrgRouteTables.
        :type ipsec_tunnel: str

        :param virtual_circuit:
            The value to assign to the virtual_circuit property of this DefaultDrgRouteTables.
        :type virtual_circuit: str

        :param remote_peering_connection:
            The value to assign to the remote_peering_connection property of this DefaultDrgRouteTables.
        :type remote_peering_connection: str

        """
        self.swagger_types = {
            'vcn': 'str',
            'ipsec_tunnel': 'str',
            'virtual_circuit': 'str',
            'remote_peering_connection': 'str'
        }

        self.attribute_map = {
            'vcn': 'vcn',
            'ipsec_tunnel': 'ipsecTunnel',
            'virtual_circuit': 'virtualCircuit',
            'remote_peering_connection': 'remotePeeringConnection'
        }

        self._vcn = None
        self._ipsec_tunnel = None
        self._virtual_circuit = None
        self._remote_peering_connection = None

    @property
    def vcn(self):
        """
        Gets the vcn of this DefaultDrgRouteTables.
        The `OCID`__ of the default DRG route table to be assigned to DRG attachments
        of type VCN on creation.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The vcn of this DefaultDrgRouteTables.
        :rtype: str
        """
        return self._vcn

    @vcn.setter
    def vcn(self, vcn):
        """
        Sets the vcn of this DefaultDrgRouteTables.
        The `OCID`__ of the default DRG route table to be assigned to DRG attachments
        of type VCN on creation.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param vcn: The vcn of this DefaultDrgRouteTables.
        :type: str
        """
        self._vcn = vcn

    @property
    def ipsec_tunnel(self):
        """
        Gets the ipsec_tunnel of this DefaultDrgRouteTables.
        The `OCID`__ of the default DRG route table assigned to DRG attachments
        of type IPSEC_TUNNEL on creation.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The ipsec_tunnel of this DefaultDrgRouteTables.
        :rtype: str
        """
        return self._ipsec_tunnel

    @ipsec_tunnel.setter
    def ipsec_tunnel(self, ipsec_tunnel):
        """
        Sets the ipsec_tunnel of this DefaultDrgRouteTables.
        The `OCID`__ of the default DRG route table assigned to DRG attachments
        of type IPSEC_TUNNEL on creation.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param ipsec_tunnel: The ipsec_tunnel of this DefaultDrgRouteTables.
        :type: str
        """
        self._ipsec_tunnel = ipsec_tunnel

    @property
    def virtual_circuit(self):
        """
        Gets the virtual_circuit of this DefaultDrgRouteTables.
        The OCID of the default DRG route table to be assigned to DRG attachments
        of type VIRTUAL_CIRCUIT on creation.


        :return: The virtual_circuit of this DefaultDrgRouteTables.
        :rtype: str
        """
        return self._virtual_circuit

    @virtual_circuit.setter
    def virtual_circuit(self, virtual_circuit):
        """
        Sets the virtual_circuit of this DefaultDrgRouteTables.
        The OCID of the default DRG route table to be assigned to DRG attachments
        of type VIRTUAL_CIRCUIT on creation.


        :param virtual_circuit: The virtual_circuit of this DefaultDrgRouteTables.
        :type: str
        """
        self._virtual_circuit = virtual_circuit

    @property
    def remote_peering_connection(self):
        """
        Gets the remote_peering_connection of this DefaultDrgRouteTables.
        The `OCID`__ of the default DRG route table to be assigned to DRG attachments
        of type REMOTE_PEERING_CONNECTION on creation.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The remote_peering_connection of this DefaultDrgRouteTables.
        :rtype: str
        """
        return self._remote_peering_connection

    @remote_peering_connection.setter
    def remote_peering_connection(self, remote_peering_connection):
        """
        Sets the remote_peering_connection of this DefaultDrgRouteTables.
        The `OCID`__ of the default DRG route table to be assigned to DRG attachments
        of type REMOTE_PEERING_CONNECTION on creation.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param remote_peering_connection: The remote_peering_connection of this DefaultDrgRouteTables.
        :type: str
        """
        self._remote_peering_connection = remote_peering_connection

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateLoadBalancerShapeDetails(object):
    """
    UpdateLoadBalancerShapeDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateLoadBalancerShapeDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param shape_name:
            The value to assign to the shape_name property of this UpdateLoadBalancerShapeDetails.
        :type shape_name: str

        :param shape_details:
            The value to assign to the shape_details property of this UpdateLoadBalancerShapeDetails.
        :type shape_details: oci.load_balancer.models.ShapeDetails

        """
        self.swagger_types = {
            'shape_name': 'str',
            'shape_details': 'ShapeDetails'
        }

        self.attribute_map = {
            'shape_name': 'shapeName',
            'shape_details': 'shapeDetails'
        }

        self._shape_name = None
        self._shape_details = None

    @property
    def shape_name(self):
        """
        **[Required]** Gets the shape_name of this UpdateLoadBalancerShapeDetails.
        The new shape name for the load balancer.

        Allowed values are :
          *  10Mbps
          *  100Mbps
          *  400Mbps
          *  8000Mbps
          *  Flexible

          Example: `Flexible`


        :return: The shape_name of this UpdateLoadBalancerShapeDetails.
        :rtype: str
        """
        return self._shape_name

    @shape_name.setter
    def shape_name(self, shape_name):
        """
        Sets the shape_name of this UpdateLoadBalancerShapeDetails.
        The new shape name for the load balancer.

        Allowed values are :
          *  10Mbps
          *  100Mbps
          *  400Mbps
          *  8000Mbps
          *  Flexible

          Example: `Flexible`


        :param shape_name: The shape_name of this UpdateLoadBalancerShapeDetails.
        :type: str
        """
        self._shape_name = shape_name

    @property
    def shape_details(self):
        """
        Gets the shape_details of this UpdateLoadBalancerShapeDetails.
        The configuration details to update load balancer to a different profile.


        :return: The shape_details of this UpdateLoadBalancerShapeDetails.
        :rtype: oci.load_balancer.models.ShapeDetails
        """
        return self._shape_details

    @shape_details.setter
    def shape_details(self, shape_details):
        """
        Sets the shape_details of this UpdateLoadBalancerShapeDetails.
        The configuration details to update load balancer to a different profile.


        :param shape_details: The shape_details of this UpdateLoadBalancerShapeDetails.
        :type: oci.load_balancer.models.ShapeDetails
        """
        self._shape_details = shape_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .change_container_repository_compartment_details import ChangeContainerRepositoryCompartmentDetails
from .change_repository_compartment_details import ChangeRepositoryCompartmentDetails
from .container_configuration import ContainerConfiguration
from .container_image import ContainerImage
from .container_image_collection import ContainerImageCollection
from .container_image_layer import ContainerImageLayer
from .container_image_signature import ContainerImageSignature
from .container_image_signature_collection import ContainerImageSignatureCollection
from .container_image_signature_summary import ContainerImageSignatureSummary
from .container_image_summary import ContainerImageSummary
from .container_repository import ContainerRepository
from .container_repository_collection import ContainerRepositoryCollection
from .container_repository_readme import ContainerRepositoryReadme
from .container_repository_summary import ContainerRepositorySummary
from .container_version import ContainerVersion
from .create_container_image_signature_details import CreateContainerImageSignatureDetails
from .create_container_repository_details import CreateContainerRepositoryDetails
from .create_generic_repository_details import CreateGenericRepositoryDetails
from .create_repository_details import CreateRepositoryDetails
from .generic_artifact import GenericArtifact
from .generic_artifact_collection import GenericArtifactCollection
from .generic_artifact_summary import GenericArtifactSummary
from .generic_repository import GenericRepository
from .generic_repository_summary import GenericRepositorySummary
from .remove_container_version_details import RemoveContainerVersionDetails
from .repository import Repository
from .repository_collection import RepositoryCollection
from .repository_summary import RepositorySummary
from .restore_container_image_details import RestoreContainerImageDetails
from .update_container_configuration_details import UpdateContainerConfigurationDetails
from .update_container_repository_details import UpdateContainerRepositoryDetails
from .update_generic_artifact_by_path_details import UpdateGenericArtifactByPathDetails
from .update_generic_artifact_details import UpdateGenericArtifactDetails
from .update_generic_repository_details import UpdateGenericRepositoryDetails
from .update_repository_details import UpdateRepositoryDetails

# Maps type names to classes for artifacts services.
artifacts_type_mapping = {
    "ChangeContainerRepositoryCompartmentDetails": ChangeContainerRepositoryCompartmentDetails,
    "ChangeRepositoryCompartmentDetails": ChangeRepositoryCompartmentDetails,
    "ContainerConfiguration": ContainerConfiguration,
    "ContainerImage": ContainerImage,
    "ContainerImageCollection": ContainerImageCollection,
    "ContainerImageLayer": ContainerImageLayer,
    "ContainerImageSignature": ContainerImageSignature,
    "ContainerImageSignatureCollection": ContainerImageSignatureCollection,
    "ContainerImageSignatureSummary": ContainerImageSignatureSummary,
    "ContainerImageSummary": ContainerImageSummary,
    "ContainerRepository": ContainerRepository,
    "ContainerRepositoryCollection": ContainerRepositoryCollection,
    "ContainerRepositoryReadme": ContainerRepositoryReadme,
    "ContainerRepositorySummary": ContainerRepositorySummary,
    "ContainerVersion": ContainerVersion,
    "CreateContainerImageSignatureDetails": CreateContainerImageSignatureDetails,
    "CreateContainerRepositoryDetails": CreateContainerRepositoryDetails,
    "CreateGenericRepositoryDetails": CreateGenericRepositoryDetails,
    "CreateRepositoryDetails": CreateRepositoryDetails,
    "GenericArtifact": GenericArtifact,
    "GenericArtifactCollection": GenericArtifactCollection,
    "GenericArtifactSummary": GenericArtifactSummary,
    "GenericRepository": GenericRepository,
    "GenericRepositorySummary": GenericRepositorySummary,
    "RemoveContainerVersionDetails": RemoveContainerVersionDetails,
    "Repository": Repository,
    "RepositoryCollection": RepositoryCollection,
    "RepositorySummary": RepositorySummary,
    "RestoreContainerImageDetails": RestoreContainerImageDetails,
    "UpdateContainerConfigurationDetails": UpdateContainerConfigurationDetails,
    "UpdateContainerRepositoryDetails": UpdateContainerRepositoryDetails,
    "UpdateGenericArtifactByPathDetails": UpdateGenericArtifactByPathDetails,
    "UpdateGenericArtifactDetails": UpdateGenericArtifactDetails,
    "UpdateGenericRepositoryDetails": UpdateGenericRepositoryDetails,
    "UpdateRepositoryDetails": UpdateRepositoryDetails
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateLookupMetadataDetails(object):
    """
    UpdateLookupMetadataDetails
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateLookupMetadataDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param default_match_value:
            The value to assign to the default_match_value property of this UpdateLookupMetadataDetails.
        :type default_match_value: str

        :param description:
            The value to assign to the description property of this UpdateLookupMetadataDetails.
        :type description: str

        :param fields:
            The value to assign to the fields property of this UpdateLookupMetadataDetails.
        :type fields: list[oci.log_analytics.models.LogAnalyticsLookupFields]

        :param max_matches:
            The value to assign to the max_matches property of this UpdateLookupMetadataDetails.
        :type max_matches: int

        """
        self.swagger_types = {
            'default_match_value': 'str',
            'description': 'str',
            'fields': 'list[LogAnalyticsLookupFields]',
            'max_matches': 'int'
        }

        self.attribute_map = {
            'default_match_value': 'defaultMatchValue',
            'description': 'description',
            'fields': 'fields',
            'max_matches': 'maxMatches'
        }

        self._default_match_value = None
        self._description = None
        self._fields = None
        self._max_matches = None

    @property
    def default_match_value(self):
        """
        Gets the default_match_value of this UpdateLookupMetadataDetails.
        The default match value.


        :return: The default_match_value of this UpdateLookupMetadataDetails.
        :rtype: str
        """
        return self._default_match_value

    @default_match_value.setter
    def default_match_value(self, default_match_value):
        """
        Sets the default_match_value of this UpdateLookupMetadataDetails.
        The default match value.


        :param default_match_value: The default_match_value of this UpdateLookupMetadataDetails.
        :type: str
        """
        self._default_match_value = default_match_value

    @property
    def description(self):
        """
        Gets the description of this UpdateLookupMetadataDetails.
        The lookup description.


        :return: The description of this UpdateLookupMetadataDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this UpdateLookupMetadataDetails.
        The lookup description.


        :param description: The description of this UpdateLookupMetadataDetails.
        :type: str
        """
        self._description = description

    @property
    def fields(self):
        """
        Gets the fields of this UpdateLookupMetadataDetails.
        The lookup fields.


        :return: The fields of this UpdateLookupMetadataDetails.
        :rtype: list[oci.log_analytics.models.LogAnalyticsLookupFields]
        """
        return self._fields

    @fields.setter
    def fields(self, fields):
        """
        Sets the fields of this UpdateLookupMetadataDetails.
        The lookup fields.


        :param fields: The fields of this UpdateLookupMetadataDetails.
        :type: list[oci.log_analytics.models.LogAnalyticsLookupFields]
        """
        self._fields = fields

    @property
    def max_matches(self):
        """
        Gets the max_matches of this UpdateLookupMetadataDetails.
        The maximum number of matches.


        :return: The max_matches of this UpdateLookupMetadataDetails.
        :rtype: int
        """
        return self._max_matches

    @max_matches.setter
    def max_matches(self, max_matches):
        """
        Sets the max_matches of this UpdateLookupMetadataDetails.
        The maximum number of matches.


        :param max_matches: The max_matches of this UpdateLookupMetadataDetails.
        :type: int
        """
        self._max_matches = max_matches

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .host_scan_agent_configuration import HostScanAgentConfiguration
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HostScanAgentConfigurationOCI(HostScanAgentConfiguration):
    """
    Agent configuration options for the OCI host scan agent
    """

    def __init__(self, **kwargs):
        """
        Initializes a new HostScanAgentConfigurationOCI object with values from keyword arguments. The default value of the :py:attr:`~oci.vulnerability_scanning.models.HostScanAgentConfigurationOCI.vendor` attribute
        of this class is ``OCI`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param vendor:
            The value to assign to the vendor property of this HostScanAgentConfigurationOCI.
            Allowed values for this property are: "OCI"
        :type vendor: str

        :param cis_benchmark_settings:
            The value to assign to the cis_benchmark_settings property of this HostScanAgentConfigurationOCI.
        :type cis_benchmark_settings: oci.vulnerability_scanning.models.HostCisBenchmarkSettings

        :param endpoint_protection_settings:
            The value to assign to the endpoint_protection_settings property of this HostScanAgentConfigurationOCI.
        :type endpoint_protection_settings: oci.vulnerability_scanning.models.HostEndpointProtectionSettings

        """
        self.swagger_types = {
            'vendor': 'str',
            'cis_benchmark_settings': 'HostCisBenchmarkSettings',
            'endpoint_protection_settings': 'HostEndpointProtectionSettings'
        }

        self.attribute_map = {
            'vendor': 'vendor',
            'cis_benchmark_settings': 'cisBenchmarkSettings',
            'endpoint_protection_settings': 'endpointProtectionSettings'
        }

        self._vendor = None
        self._cis_benchmark_settings = None
        self._endpoint_protection_settings = None
        self._vendor = 'OCI'

    @property
    def cis_benchmark_settings(self):
        """
        Gets the cis_benchmark_settings of this HostScanAgentConfigurationOCI.

        :return: The cis_benchmark_settings of this HostScanAgentConfigurationOCI.
        :rtype: oci.vulnerability_scanning.models.HostCisBenchmarkSettings
        """
        return self._cis_benchmark_settings

    @cis_benchmark_settings.setter
    def cis_benchmark_settings(self, cis_benchmark_settings):
        """
        Sets the cis_benchmark_settings of this HostScanAgentConfigurationOCI.

        :param cis_benchmark_settings: The cis_benchmark_settings of this HostScanAgentConfigurationOCI.
        :type: oci.vulnerability_scanning.models.HostCisBenchmarkSettings
        """
        self._cis_benchmark_settings = cis_benchmark_settings

    @property
    def endpoint_protection_settings(self):
        """
        Gets the endpoint_protection_settings of this HostScanAgentConfigurationOCI.

        :return: The endpoint_protection_settings of this HostScanAgentConfigurationOCI.
        :rtype: oci.vulnerability_scanning.models.HostEndpointProtectionSettings
        """
        return self._endpoint_protection_settings

    @endpoint_protection_settings.setter
    def endpoint_protection_settings(self, endpoint_protection_settings):
        """
        Sets the endpoint_protection_settings of this HostScanAgentConfigurationOCI.

        :param endpoint_protection_settings: The endpoint_protection_settings of this HostScanAgentConfigurationOCI.
        :type: oci.vulnerability_scanning.models.HostEndpointProtectionSettings
        """
        self._endpoint_protection_settings = endpoint_protection_settings

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RoverNode(object):
    """
    Information about a RoverNode.
    """

    #: A constant which can be used with the node_type property of a RoverNode.
    #: This constant has a value of "STANDALONE"
    NODE_TYPE_STANDALONE = "STANDALONE"

    #: A constant which can be used with the node_type property of a RoverNode.
    #: This constant has a value of "CLUSTERED"
    NODE_TYPE_CLUSTERED = "CLUSTERED"

    #: A constant which can be used with the enclosure_type property of a RoverNode.
    #: This constant has a value of "RUGGADIZED"
    ENCLOSURE_TYPE_RUGGADIZED = "RUGGADIZED"

    #: A constant which can be used with the enclosure_type property of a RoverNode.
    #: This constant has a value of "NON_RUGGADIZED"
    ENCLOSURE_TYPE_NON_RUGGADIZED = "NON_RUGGADIZED"

    #: A constant which can be used with the lifecycle_state property of a RoverNode.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a RoverNode.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a RoverNode.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a RoverNode.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a RoverNode.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a RoverNode.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the shipping_preference property of a RoverNode.
    #: This constant has a value of "ORACLE_SHIPPED"
    SHIPPING_PREFERENCE_ORACLE_SHIPPED = "ORACLE_SHIPPED"

    #: A constant which can be used with the shipping_preference property of a RoverNode.
    #: This constant has a value of "CUSTOMER_PICKUP"
    SHIPPING_PREFERENCE_CUSTOMER_PICKUP = "CUSTOMER_PICKUP"

    def __init__(self, **kwargs):
        """
        Initializes a new RoverNode object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this RoverNode.
        :type id: str

        :param cluster_id:
            The value to assign to the cluster_id property of this RoverNode.
        :type cluster_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this RoverNode.
        :type compartment_id: str

        :param node_type:
            The value to assign to the node_type property of this RoverNode.
            Allowed values for this property are: "STANDALONE", "CLUSTERED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type node_type: str

        :param enclosure_type:
            The value to assign to the enclosure_type property of this RoverNode.
            Allowed values for this property are: "RUGGADIZED", "NON_RUGGADIZED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type enclosure_type: str

        :param serial_number:
            The value to assign to the serial_number property of this RoverNode.
        :type serial_number: str

        :param display_name:
            The value to assign to the display_name property of this RoverNode.
        :type display_name: str

        :param time_created:
            The value to assign to the time_created property of this RoverNode.
        :type time_created: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this RoverNode.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_state_details:
            The value to assign to the lifecycle_state_details property of this RoverNode.
        :type lifecycle_state_details: str

        :param customer_shipping_address:
            The value to assign to the customer_shipping_address property of this RoverNode.
        :type customer_shipping_address: oci.rover.models.ShippingAddress

        :param node_workloads:
            The value to assign to the node_workloads property of this RoverNode.
        :type node_workloads: list[oci.rover.models.RoverWorkload]

        :param time_customer_receieved:
            The value to assign to the time_customer_receieved property of this RoverNode.
        :type time_customer_receieved: datetime

        :param time_customer_returned:
            The value to assign to the time_customer_returned property of this RoverNode.
        :type time_customer_returned: datetime

        :param delivery_tracking_info:
            The value to assign to the delivery_tracking_info property of this RoverNode.
        :type delivery_tracking_info: str

        :param super_user_password:
            The value to assign to the super_user_password property of this RoverNode.
        :type super_user_password: str

        :param unlock_passphrase:
            The value to assign to the unlock_passphrase property of this RoverNode.
        :type unlock_passphrase: str

        :param point_of_contact:
            The value to assign to the point_of_contact property of this RoverNode.
        :type point_of_contact: str

        :param point_of_contact_phone_number:
            The value to assign to the point_of_contact_phone_number property of this RoverNode.
        :type point_of_contact_phone_number: str

        :param shipping_preference:
            The value to assign to the shipping_preference property of this RoverNode.
            Allowed values for this property are: "ORACLE_SHIPPED", "CUSTOMER_PICKUP", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type shipping_preference: str

        :param shipping_vendor:
            The value to assign to the shipping_vendor property of this RoverNode.
        :type shipping_vendor: str

        :param time_pickup_expected:
            The value to assign to the time_pickup_expected property of this RoverNode.
        :type time_pickup_expected: datetime

        :param time_return_window_starts:
            The value to assign to the time_return_window_starts property of this RoverNode.
        :type time_return_window_starts: datetime

        :param oracle_shipping_tracking_url:
            The value to assign to the oracle_shipping_tracking_url property of this RoverNode.
        :type oracle_shipping_tracking_url: str

        :param time_return_window_ends:
            The value to assign to the time_return_window_ends property of this RoverNode.
        :type time_return_window_ends: datetime

        :param return_shipping_label_uri:
            The value to assign to the return_shipping_label_uri property of this RoverNode.
        :type return_shipping_label_uri: str

        :param public_key:
            The value to assign to the public_key property of this RoverNode.
        :type public_key: str

        :param image_export_par:
            The value to assign to the image_export_par property of this RoverNode.
        :type image_export_par: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this RoverNode.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this RoverNode.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this RoverNode.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'cluster_id': 'str',
            'compartment_id': 'str',
            'node_type': 'str',
            'enclosure_type': 'str',
            'serial_number': 'str',
            'display_name': 'str',
            'time_created': 'datetime',
            'lifecycle_state': 'str',
            'lifecycle_state_details': 'str',
            'customer_shipping_address': 'ShippingAddress',
            'node_workloads': 'list[RoverWorkload]',
            'time_customer_receieved': 'datetime',
            'time_customer_returned': 'datetime',
            'delivery_tracking_info': 'str',
            'super_user_password': 'str',
            'unlock_passphrase': 'str',
            'point_of_contact': 'str',
            'point_of_contact_phone_number': 'str',
            'shipping_preference': 'str',
            'shipping_vendor': 'str',
            'time_pickup_expected': 'datetime',
            'time_return_window_starts': 'datetime',
            'oracle_shipping_tracking_url': 'str',
            'time_return_window_ends': 'datetime',
            'return_shipping_label_uri': 'str',
            'public_key': 'str',
            'image_export_par': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'cluster_id': 'clusterId',
            'compartment_id': 'compartmentId',
            'node_type': 'nodeType',
            'enclosure_type': 'enclosureType',
            'serial_number': 'serialNumber',
            'display_name': 'displayName',
            'time_created': 'timeCreated',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_state_details': 'lifecycleStateDetails',
            'customer_shipping_address': 'customerShippingAddress',
            'node_workloads': 'nodeWorkloads',
            'time_customer_receieved': 'timeCustomerReceieved',
            'time_customer_returned': 'timeCustomerReturned',
            'delivery_tracking_info': 'deliveryTrackingInfo',
            'super_user_password': 'superUserPassword',
            'unlock_passphrase': 'unlockPassphrase',
            'point_of_contact': 'pointOfContact',
            'point_of_contact_phone_number': 'pointOfContactPhoneNumber',
            'shipping_preference': 'shippingPreference',
            'shipping_vendor': 'shippingVendor',
            'time_pickup_expected': 'timePickupExpected',
            'time_return_window_starts': 'timeReturnWindowStarts',
            'oracle_shipping_tracking_url': 'oracleShippingTrackingUrl',
            'time_return_window_ends': 'timeReturnWindowEnds',
            'return_shipping_label_uri': 'returnShippingLabelUri',
            'public_key': 'publicKey',
            'image_export_par': 'imageExportPar',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._id = None
        self._cluster_id = None
        self._compartment_id = None
        self._node_type = None
        self._enclosure_type = None
        self._serial_number = None
        self._display_name = None
        self._time_created = None
        self._lifecycle_state = None
        self._lifecycle_state_details = None
        self._customer_shipping_address = None
        self._node_workloads = None
        self._time_customer_receieved = None
        self._time_customer_returned = None
        self._delivery_tracking_info = None
        self._super_user_password = None
        self._unlock_passphrase = None
        self._point_of_contact = None
        self._point_of_contact_phone_number = None
        self._shipping_preference = None
        self._shipping_vendor = None
        self._time_pickup_expected = None
        self._time_return_window_starts = None
        self._oracle_shipping_tracking_url = None
        self._time_return_window_ends = None
        self._return_shipping_label_uri = None
        self._public_key = None
        self._image_export_par = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this RoverNode.
        The OCID of RoverNode.


        :return: The id of this RoverNode.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this RoverNode.
        The OCID of RoverNode.


        :param id: The id of this RoverNode.
        :type: str
        """
        self._id = id

    @property
    def cluster_id(self):
        """
        Gets the cluster_id of this RoverNode.
        The cluster ID if the node is part of a cluster.


        :return: The cluster_id of this RoverNode.
        :rtype: str
        """
        return self._cluster_id

    @cluster_id.setter
    def cluster_id(self, cluster_id):
        """
        Sets the cluster_id of this RoverNode.
        The cluster ID if the node is part of a cluster.


        :param cluster_id: The cluster_id of this RoverNode.
        :type: str
        """
        self._cluster_id = cluster_id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this RoverNode.
        The OCID of the compartment containing the RoverNode.


        :return: The compartment_id of this RoverNode.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this RoverNode.
        The OCID of the compartment containing the RoverNode.


        :param compartment_id: The compartment_id of this RoverNode.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def node_type(self):
        """
        Gets the node_type of this RoverNode.
        The type of node indicating if it belongs to a cluster

        Allowed values for this property are: "STANDALONE", "CLUSTERED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The node_type of this RoverNode.
        :rtype: str
        """
        return self._node_type

    @node_type.setter
    def node_type(self, node_type):
        """
        Sets the node_type of this RoverNode.
        The type of node indicating if it belongs to a cluster


        :param node_type: The node_type of this RoverNode.
        :type: str
        """
        allowed_values = ["STANDALONE", "CLUSTERED"]
        if not value_allowed_none_or_none_sentinel(node_type, allowed_values):
            node_type = 'UNKNOWN_ENUM_VALUE'
        self._node_type = node_type

    @property
    def enclosure_type(self):
        """
        Gets the enclosure_type of this RoverNode.
        The type of enclosure rover node is shipped in.

        Allowed values for this property are: "RUGGADIZED", "NON_RUGGADIZED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The enclosure_type of this RoverNode.
        :rtype: str
        """
        return self._enclosure_type

    @enclosure_type.setter
    def enclosure_type(self, enclosure_type):
        """
        Sets the enclosure_type of this RoverNode.
        The type of enclosure rover node is shipped in.


        :param enclosure_type: The enclosure_type of this RoverNode.
        :type: str
        """
        allowed_values = ["RUGGADIZED", "NON_RUGGADIZED"]
        if not value_allowed_none_or_none_sentinel(enclosure_type, allowed_values):
            enclosure_type = 'UNKNOWN_ENUM_VALUE'
        self._enclosure_type = enclosure_type

    @property
    def serial_number(self):
        """
        Gets the serial_number of this RoverNode.
        Serial number of the node.


        :return: The serial_number of this RoverNode.
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """
        Sets the serial_number of this RoverNode.
        Serial number of the node.


        :param serial_number: The serial_number of this RoverNode.
        :type: str
        """
        self._serial_number = serial_number

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this RoverNode.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.


        :return: The display_name of this RoverNode.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this RoverNode.
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.


        :param display_name: The display_name of this RoverNode.
        :type: str
        """
        self._display_name = display_name

    @property
    def time_created(self):
        """
        Gets the time_created of this RoverNode.
        The time the the RoverNode was created. An RFC3339 formatted datetime string


        :return: The time_created of this RoverNode.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this RoverNode.
        The time the the RoverNode was created. An RFC3339 formatted datetime string


        :param time_created: The time_created of this RoverNode.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this RoverNode.
        The current state of the RoverNode.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this RoverNode.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this RoverNode.
        The current state of the RoverNode.


        :param lifecycle_state: The lifecycle_state of this RoverNode.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_state_details(self):
        """
        Gets the lifecycle_state_details of this RoverNode.
        A property that can contain details on the lifecycle.


        :return: The lifecycle_state_details of this RoverNode.
        :rtype: str
        """
        return self._lifecycle_state_details

    @lifecycle_state_details.setter
    def lifecycle_state_details(self, lifecycle_state_details):
        """
        Sets the lifecycle_state_details of this RoverNode.
        A property that can contain details on the lifecycle.


        :param lifecycle_state_details: The lifecycle_state_details of this RoverNode.
        :type: str
        """
        self._lifecycle_state_details = lifecycle_state_details

    @property
    def customer_shipping_address(self):
        """
        Gets the customer_shipping_address of this RoverNode.

        :return: The customer_shipping_address of this RoverNode.
        :rtype: oci.rover.models.ShippingAddress
        """
        return self._customer_shipping_address

    @customer_shipping_address.setter
    def customer_shipping_address(self, customer_shipping_address):
        """
        Sets the customer_shipping_address of this RoverNode.

        :param customer_shipping_address: The customer_shipping_address of this RoverNode.
        :type: oci.rover.models.ShippingAddress
        """
        self._customer_shipping_address = customer_shipping_address

    @property
    def node_workloads(self):
        """
        Gets the node_workloads of this RoverNode.
        List of existing workloads that should be provisioned on the node.


        :return: The node_workloads of this RoverNode.
        :rtype: list[oci.rover.models.RoverWorkload]
        """
        return self._node_workloads

    @node_workloads.setter
    def node_workloads(self, node_workloads):
        """
        Sets the node_workloads of this RoverNode.
        List of existing workloads that should be provisioned on the node.


        :param node_workloads: The node_workloads of this RoverNode.
        :type: list[oci.rover.models.RoverWorkload]
        """
        self._node_workloads = node_workloads

    @property
    def time_customer_receieved(self):
        """
        Gets the time_customer_receieved of this RoverNode.
        Date and time when customer received tne node.


        :return: The time_customer_receieved of this RoverNode.
        :rtype: datetime
        """
        return self._time_customer_receieved

    @time_customer_receieved.setter
    def time_customer_receieved(self, time_customer_receieved):
        """
        Sets the time_customer_receieved of this RoverNode.
        Date and time when customer received tne node.


        :param time_customer_receieved: The time_customer_receieved of this RoverNode.
        :type: datetime
        """
        self._time_customer_receieved = time_customer_receieved

    @property
    def time_customer_returned(self):
        """
        Gets the time_customer_returned of this RoverNode.
        Date and time when customer returned the node.


        :return: The time_customer_returned of this RoverNode.
        :rtype: datetime
        """
        return self._time_customer_returned

    @time_customer_returned.setter
    def time_customer_returned(self, time_customer_returned):
        """
        Sets the time_customer_returned of this RoverNode.
        Date and time when customer returned the node.


        :param time_customer_returned: The time_customer_returned of this RoverNode.
        :type: datetime
        """
        self._time_customer_returned = time_customer_returned

    @property
    def delivery_tracking_info(self):
        """
        Gets the delivery_tracking_info of this RoverNode.
        Tracking information for device shipping.


        :return: The delivery_tracking_info of this RoverNode.
        :rtype: str
        """
        return self._delivery_tracking_info

    @delivery_tracking_info.setter
    def delivery_tracking_info(self, delivery_tracking_info):
        """
        Sets the delivery_tracking_info of this RoverNode.
        Tracking information for device shipping.


        :param delivery_tracking_info: The delivery_tracking_info of this RoverNode.
        :type: str
        """
        self._delivery_tracking_info = delivery_tracking_info

    @property
    def super_user_password(self):
        """
        Gets the super_user_password of this RoverNode.
        Root password for the rover node.


        :return: The super_user_password of this RoverNode.
        :rtype: str
        """
        return self._super_user_password

    @super_user_password.setter
    def super_user_password(self, super_user_password):
        """
        Sets the super_user_password of this RoverNode.
        Root password for the rover node.


        :param super_user_password: The super_user_password of this RoverNode.
        :type: str
        """
        self._super_user_password = super_user_password

    @property
    def unlock_passphrase(self):
        """
        Gets the unlock_passphrase of this RoverNode.
        Password to unlock the rover node.


        :return: The unlock_passphrase of this RoverNode.
        :rtype: str
        """
        return self._unlock_passphrase

    @unlock_passphrase.setter
    def unlock_passphrase(self, unlock_passphrase):
        """
        Sets the unlock_passphrase of this RoverNode.
        Password to unlock the rover node.


        :param unlock_passphrase: The unlock_passphrase of this RoverNode.
        :type: str
        """
        self._unlock_passphrase = unlock_passphrase

    @property
    def point_of_contact(self):
        """
        Gets the point_of_contact of this RoverNode.
        Name of point of contact for this order if customer is picking up.


        :return: The point_of_contact of this RoverNode.
        :rtype: str
        """
        return self._point_of_contact

    @point_of_contact.setter
    def point_of_contact(self, point_of_contact):
        """
        Sets the point_of_contact of this RoverNode.
        Name of point of contact for this order if customer is picking up.


        :param point_of_contact: The point_of_contact of this RoverNode.
        :type: str
        """
        self._point_of_contact = point_of_contact

    @property
    def point_of_contact_phone_number(self):
        """
        Gets the point_of_contact_phone_number of this RoverNode.
        Phone number of point of contact for this order if customer is picking up.


        :return: The point_of_contact_phone_number of this RoverNode.
        :rtype: str
        """
        return self._point_of_contact_phone_number

    @point_of_contact_phone_number.setter
    def point_of_contact_phone_number(self, point_of_contact_phone_number):
        """
        Sets the point_of_contact_phone_number of this RoverNode.
        Phone number of point of contact for this order if customer is picking up.


        :param point_of_contact_phone_number: The point_of_contact_phone_number of this RoverNode.
        :type: str
        """
        self._point_of_contact_phone_number = point_of_contact_phone_number

    @property
    def shipping_preference(self):
        """
        Gets the shipping_preference of this RoverNode.
        Preference for device delivery.

        Allowed values for this property are: "ORACLE_SHIPPED", "CUSTOMER_PICKUP", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The shipping_preference of this RoverNode.
        :rtype: str
        """
        return self._shipping_preference

    @shipping_preference.setter
    def shipping_preference(self, shipping_preference):
        """
        Sets the shipping_preference of this RoverNode.
        Preference for device delivery.


        :param shipping_preference: The shipping_preference of this RoverNode.
        :type: str
        """
        allowed_values = ["ORACLE_SHIPPED", "CUSTOMER_PICKUP"]
        if not value_allowed_none_or_none_sentinel(shipping_preference, allowed_values):
            shipping_preference = 'UNKNOWN_ENUM_VALUE'
        self._shipping_preference = shipping_preference

    @property
    def shipping_vendor(self):
        """
        Gets the shipping_vendor of this RoverNode.
        Shipping vendor of choice for orace to customer shipping.


        :return: The shipping_vendor of this RoverNode.
        :rtype: str
        """
        return self._shipping_vendor

    @shipping_vendor.setter
    def shipping_vendor(self, shipping_vendor):
        """
        Sets the shipping_vendor of this RoverNode.
        Shipping vendor of choice for orace to customer shipping.


        :param shipping_vendor: The shipping_vendor of this RoverNode.
        :type: str
        """
        self._shipping_vendor = shipping_vendor

    @property
    def time_pickup_expected(self):
        """
        Gets the time_pickup_expected of this RoverNode.
        Expected date when customer wants to pickup the device if they chose customer pickup.


        :return: The time_pickup_expected of this RoverNode.
        :rtype: datetime
        """
        return self._time_pickup_expected

    @time_pickup_expected.setter
    def time_pickup_expected(self, time_pickup_expected):
        """
        Sets the time_pickup_expected of this RoverNode.
        Expected date when customer wants to pickup the device if they chose customer pickup.


        :param time_pickup_expected: The time_pickup_expected of this RoverNode.
        :type: datetime
        """
        self._time_pickup_expected = time_pickup_expected

    @property
    def time_return_window_starts(self):
        """
        Gets the time_return_window_starts of this RoverNode.
        Start time for the window to pickup the device from customer.


        :return: The time_return_window_starts of this RoverNode.
        :rtype: datetime
        """
        return self._time_return_window_starts

    @time_return_window_starts.setter
    def time_return_window_starts(self, time_return_window_starts):
        """
        Sets the time_return_window_starts of this RoverNode.
        Start time for the window to pickup the device from customer.


        :param time_return_window_starts: The time_return_window_starts of this RoverNode.
        :type: datetime
        """
        self._time_return_window_starts = time_return_window_starts

    @property
    def oracle_shipping_tracking_url(self):
        """
        Gets the oracle_shipping_tracking_url of this RoverNode.
        Tracking Url for the shipped RoverNode.


        :return: The oracle_shipping_tracking_url of this RoverNode.
        :rtype: str
        """
        return self._oracle_shipping_tracking_url

    @oracle_shipping_tracking_url.setter
    def oracle_shipping_tracking_url(self, oracle_shipping_tracking_url):
        """
        Sets the oracle_shipping_tracking_url of this RoverNode.
        Tracking Url for the shipped RoverNode.


        :param oracle_shipping_tracking_url: The oracle_shipping_tracking_url of this RoverNode.
        :type: str
        """
        self._oracle_shipping_tracking_url = oracle_shipping_tracking_url

    @property
    def time_return_window_ends(self):
        """
        Gets the time_return_window_ends of this RoverNode.
        End time for the window to pickup the device from customer.


        :return: The time_return_window_ends of this RoverNode.
        :rtype: datetime
        """
        return self._time_return_window_ends

    @time_return_window_ends.setter
    def time_return_window_ends(self, time_return_window_ends):
        """
        Sets the time_return_window_ends of this RoverNode.
        End time for the window to pickup the device from customer.


        :param time_return_window_ends: The time_return_window_ends of this RoverNode.
        :type: datetime
        """
        self._time_return_window_ends = time_return_window_ends

    @property
    def return_shipping_label_uri(self):
        """
        Gets the return_shipping_label_uri of this RoverNode.
        Uri to download return shipping label.


        :return: The return_shipping_label_uri of this RoverNode.
        :rtype: str
        """
        return self._return_shipping_label_uri

    @return_shipping_label_uri.setter
    def return_shipping_label_uri(self, return_shipping_label_uri):
        """
        Sets the return_shipping_label_uri of this RoverNode.
        Uri to download return shipping label.


        :param return_shipping_label_uri: The return_shipping_label_uri of this RoverNode.
        :type: str
        """
        self._return_shipping_label_uri = return_shipping_label_uri

    @property
    def public_key(self):
        """
        Gets the public_key of this RoverNode.
        The public key of the resource principal


        :return: The public_key of this RoverNode.
        :rtype: str
        """
        return self._public_key

    @public_key.setter
    def public_key(self, public_key):
        """
        Sets the public_key of this RoverNode.
        The public key of the resource principal


        :param public_key: The public_key of this RoverNode.
        :type: str
        """
        self._public_key = public_key

    @property
    def image_export_par(self):
        """
        Gets the image_export_par of this RoverNode.
        The link to pre-authenticated request for a bucket where image workloads are moved.


        :return: The image_export_par of this RoverNode.
        :rtype: str
        """
        return self._image_export_par

    @image_export_par.setter
    def image_export_par(self, image_export_par):
        """
        Sets the image_export_par of this RoverNode.
        The link to pre-authenticated request for a bucket where image workloads are moved.


        :param image_export_par: The image_export_par of this RoverNode.
        :type: str
        """
        self._image_export_par = image_export_par

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this RoverNode.
        The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this RoverNode.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this RoverNode.
        The freeform tags associated with this resource, if any. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.
        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this RoverNode.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this RoverNode.
        The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this RoverNode.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this RoverNode.
        The defined tags associated with this resource, if any. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this RoverNode.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this RoverNode.
        The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{orcl-cloud: {free-tier-retain: true}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The system_tags of this RoverNode.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this RoverNode.
        The system tags associated with this resource, if any. The system tags are set by Oracle cloud infrastructure services. Each key is predefined and scoped to namespaces.
        For more information, see `Resource Tags`__.
        Example: `{orcl-cloud: {free-tier-retain: true}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param system_tags: The system_tags of this RoverNode.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import


from .access_requests_client import AccessRequestsClient
from .access_requests_client_composite_operations import AccessRequestsClientCompositeOperations
from .operator_actions_client import OperatorActionsClient
from .operator_actions_client_composite_operations import OperatorActionsClientCompositeOperations
from .operator_control_client import OperatorControlClient
from .operator_control_client_composite_operations import OperatorControlClientCompositeOperations
from .operator_control_assignment_client import OperatorControlAssignmentClient
from .operator_control_assignment_client_composite_operations import OperatorControlAssignmentClientCompositeOperations
from . import models

__all__ = ["AccessRequestsClient", "AccessRequestsClientCompositeOperations", "OperatorActionsClient", "OperatorActionsClientCompositeOperations", "OperatorControlClient", "OperatorControlClientCompositeOperations", "OperatorControlAssignmentClient", "OperatorControlAssignmentClientCompositeOperations", "models"]



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AssociableEntity(object):
    """
    Entity details including whether or not it is eligible for association with the source.
    """

    #: A constant which can be used with the eligibility_status property of a AssociableEntity.
    #: This constant has a value of "ELIGIBLE"
    ELIGIBILITY_STATUS_ELIGIBLE = "ELIGIBLE"

    #: A constant which can be used with the eligibility_status property of a AssociableEntity.
    #: This constant has a value of "INELIGIBLE"
    ELIGIBILITY_STATUS_INELIGIBLE = "INELIGIBLE"

    def __init__(self, **kwargs):
        """
        Initializes a new AssociableEntity object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity_id:
            The value to assign to the entity_id property of this AssociableEntity.
        :type entity_id: str

        :param entity_name:
            The value to assign to the entity_name property of this AssociableEntity.
        :type entity_name: str

        :param entity_type_name:
            The value to assign to the entity_type_name property of this AssociableEntity.
        :type entity_type_name: str

        :param entity_type_display_name:
            The value to assign to the entity_type_display_name property of this AssociableEntity.
        :type entity_type_display_name: str

        :param host:
            The value to assign to the host property of this AssociableEntity.
        :type host: str

        :param agent_id:
            The value to assign to the agent_id property of this AssociableEntity.
        :type agent_id: str

        :param eligibility_status:
            The value to assign to the eligibility_status property of this AssociableEntity.
            Allowed values for this property are: "ELIGIBLE", "INELIGIBLE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type eligibility_status: str

        :param ineligibility_details:
            The value to assign to the ineligibility_details property of this AssociableEntity.
        :type ineligibility_details: str

        """
        self.swagger_types = {
            'entity_id': 'str',
            'entity_name': 'str',
            'entity_type_name': 'str',
            'entity_type_display_name': 'str',
            'host': 'str',
            'agent_id': 'str',
            'eligibility_status': 'str',
            'ineligibility_details': 'str'
        }

        self.attribute_map = {
            'entity_id': 'entityId',
            'entity_name': 'entityName',
            'entity_type_name': 'entityTypeName',
            'entity_type_display_name': 'entityTypeDisplayName',
            'host': 'host',
            'agent_id': 'agentId',
            'eligibility_status': 'eligibilityStatus',
            'ineligibility_details': 'ineligibilityDetails'
        }

        self._entity_id = None
        self._entity_name = None
        self._entity_type_name = None
        self._entity_type_display_name = None
        self._host = None
        self._agent_id = None
        self._eligibility_status = None
        self._ineligibility_details = None

    @property
    def entity_id(self):
        """
        Gets the entity_id of this AssociableEntity.
        The entity OCID.


        :return: The entity_id of this AssociableEntity.
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """
        Sets the entity_id of this AssociableEntity.
        The entity OCID.


        :param entity_id: The entity_id of this AssociableEntity.
        :type: str
        """
        self._entity_id = entity_id

    @property
    def entity_name(self):
        """
        Gets the entity_name of this AssociableEntity.
        The name of the entity.


        :return: The entity_name of this AssociableEntity.
        :rtype: str
        """
        return self._entity_name

    @entity_name.setter
    def entity_name(self, entity_name):
        """
        Sets the entity_name of this AssociableEntity.
        The name of the entity.


        :param entity_name: The entity_name of this AssociableEntity.
        :type: str
        """
        self._entity_name = entity_name

    @property
    def entity_type_name(self):
        """
        Gets the entity_type_name of this AssociableEntity.
        The type name of the entity.


        :return: The entity_type_name of this AssociableEntity.
        :rtype: str
        """
        return self._entity_type_name

    @entity_type_name.setter
    def entity_type_name(self, entity_type_name):
        """
        Sets the entity_type_name of this AssociableEntity.
        The type name of the entity.


        :param entity_type_name: The entity_type_name of this AssociableEntity.
        :type: str
        """
        self._entity_type_name = entity_type_name

    @property
    def entity_type_display_name(self):
        """
        Gets the entity_type_display_name of this AssociableEntity.
        The display name of the entity type.


        :return: The entity_type_display_name of this AssociableEntity.
        :rtype: str
        """
        return self._entity_type_display_name

    @entity_type_display_name.setter
    def entity_type_display_name(self, entity_type_display_name):
        """
        Sets the entity_type_display_name of this AssociableEntity.
        The display name of the entity type.


        :param entity_type_display_name: The entity_type_display_name of this AssociableEntity.
        :type: str
        """
        self._entity_type_display_name = entity_type_display_name

    @property
    def host(self):
        """
        Gets the host of this AssociableEntity.
        The entity host.


        :return: The host of this AssociableEntity.
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """
        Sets the host of this AssociableEntity.
        The entity host.


        :param host: The host of this AssociableEntity.
        :type: str
        """
        self._host = host

    @property
    def agent_id(self):
        """
        Gets the agent_id of this AssociableEntity.
        The OCID of the Management Agent.


        :return: The agent_id of this AssociableEntity.
        :rtype: str
        """
        return self._agent_id

    @agent_id.setter
    def agent_id(self, agent_id):
        """
        Sets the agent_id of this AssociableEntity.
        The OCID of the Management Agent.


        :param agent_id: The agent_id of this AssociableEntity.
        :type: str
        """
        self._agent_id = agent_id

    @property
    def eligibility_status(self):
        """
        Gets the eligibility_status of this AssociableEntity.
        This field indicates whether the entity is (in)eligible to be associated with this source.

        Allowed values for this property are: "ELIGIBLE", "INELIGIBLE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The eligibility_status of this AssociableEntity.
        :rtype: str
        """
        return self._eligibility_status

    @eligibility_status.setter
    def eligibility_status(self, eligibility_status):
        """
        Sets the eligibility_status of this AssociableEntity.
        This field indicates whether the entity is (in)eligible to be associated with this source.


        :param eligibility_status: The eligibility_status of this AssociableEntity.
        :type: str
        """
        allowed_values = ["ELIGIBLE", "INELIGIBLE"]
        if not value_allowed_none_or_none_sentinel(eligibility_status, allowed_values):
            eligibility_status = 'UNKNOWN_ENUM_VALUE'
        self._eligibility_status = eligibility_status

    @property
    def ineligibility_details(self):
        """
        Gets the ineligibility_details of this AssociableEntity.
        The reason the entity is not eligible for association.


        :return: The ineligibility_details of this AssociableEntity.
        :rtype: str
        """
        return self._ineligibility_details

    @ineligibility_details.setter
    def ineligibility_details(self, ineligibility_details):
        """
        Sets the ineligibility_details of this AssociableEntity.
        The reason the entity is not eligible for association.


        :param ineligibility_details: The ineligibility_details of this AssociableEntity.
        :type: str
        """
        self._ineligibility_details = ineligibility_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
